![Bump version](https://github.com/jupyter-naas/drivers/workflows/Bump%20version/badge.svg)
![Test Python package](https://github.com/jupyter-naas/drivers/workflows/Test%20Python%20package/badge.svg)
![Upload Python Package](https://github.com/jupyter-naas/drivers/workflows/Upload%20Python%20Package/badge.svg)
![codecov](https://codecov.io/gh/jupyter-naas/drivers/branch/master/graph/badge.svg?token=IUF0AKYEB0)

# Drivers
🏎 Simple formulas to build highly efficient scripts

## Check lint

`python3 -m black naas` format better
`python3 -m flake8 naas` check if any left error

## Publish

Allow easy deploy by setting password in keyring
`python3 -m keyring set https://upload.pypi.org/legacy/ bobapp`


### Authors:
* [Martin donadieu](https://github.com/riderx)